Turbotools
^^^^^^^^^^^^^^^^

.. image:: https://travis-ci.org/anshengme/turbotools.svg?branch=master
   :target: https://travis-ci.org/anshengme/turbotools

.. image:: https://coveralls.io/repos/github/anshengme/turbotools/badge.svg?branch=master
   :target: https://coveralls.io/github/anshengme/turbotools?branch=master

.. image:: https://img.shields.io/pypi/v/turbotools.svg?
   :target: http://badge.fury.io/py/turbotools

.. image:: https://img.shields.io/pypi/pyversions/turbotools.svg
   :target: https://github.com/anshengme/turbotools

.. image:: https://img.shields.io/github/license/mashape/apistatus.svg
   :target: https://github.com/anshengme/turbotools/blob/master/LICENSE


发布PyPi
----------------

::

    python setup.py sdist
    twine upload dist/*